<?php

/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

/**
 * Update a note.  If the note doesn't exist, creates a new one and saves it.
 */

$note = new Note("", "", getRequestUser()->getUID(), null);

$newnote = true;
if (!empty($VARS['id'])) {
    try {
        $note = Note::loadNote($VARS['id']);
        $newnote = false;
    } catch (Exception $ex) {
        // It's a new note I guess
        $newnote = true;
    }
}

if ($newnote && $SETTINGS['note_limit'] !== false && !getRequestUser()->hasPermission($SETTINGS['unlimited_permission'])) {
    $notecount = $database->count("notes", ['ownerid' => getRequestUser()->getUID()]);
    if ($notecount >= $SETTINGS['note_limit']) {
        sendJsonResp($Strings->get("You've reached your quota limit and can't make new notes.", false), "ERROR");
    }
}

if (!$note->hasWriteAccess(getRequestUser())) {
    sendJsonResp($Strings->get("You don't have permission to edit this note.", false), "ERROR");
}


$note->setText($VARS['text']);

if (!empty($VARS['color'])) {
    $note->setColor($VARS['color']);
}

if (empty($VARS['modified'])) {
    $note->setModified(date("Y-m-d H:i:s"));
} else {
    $note->setModified($VARS['modified']);
}

if (!empty($VARS['favorite'])) {
    $note->setFavorite($VARS['favorite'] == true);
}

$note->saveNote();

sendJsonResp($Strings->get("Note saved", false), "OK", ["note" => $note->toArray()]);
